# GoatPie
[![Build](https://ci.codeberg.org/api/badges/refbw/goatpie/status.svg)](https://codeberg.org/refbw/goatpie/issues)

"GoatCounter" analytics for the CLI, written in Python - get it?

**Note**: This project is a *work in progress* and subject to breaking changes on a daily basis!


### Screenshot

![Screenshot](screenshot.png)


## Roadmap

- [ ] Add tests
- [ ] Config file
